@@ -35,11 +35,12 @@
 **/
 
 
-#ifndef _H_COREARRAY_BIT_
-#define _H_COREARRAY_BIT_
+#ifndef _HEADER_COREARRAY_BIT_
+#define _HEADER_COREARRAY_BIT_
 
 #include <CoreDEF.h>
 #include <dType.h>
+#include <dTrait.h>
 
 
 namespace CoreArray
@@ -49,23 +50,30 @@ namespace CoreArray
 		/// The structure to define the extended integer types
 		/** \tparam TYPE    integer type
 		 *  \return         the extended integer type with more bytes,
-		 *                  e.g., Int8 returns Int16
+		 *                  e.g., C_Int8 returns C_Int16
 		 *  \sa  BIT_INTEGER
 		**/
-		template<typename TYPE> struct TypeExtend {};
+		template<typename TYPE> struct COREARRAY_DLL_DEFAULT TypeExtend
+			{ };
 
-		/// Integer extended: Int8 -> Int16
-		template<> struct TypeExtend<Int8>   { typedef Int16  Type; };
-		/// Integer extended: UInt8 -> UInt16
-		template<> struct TypeExtend<UInt8>  { typedef UInt16 Type; };
-		/// Integer extended: Int16 -> Int32
-		template<> struct TypeExtend<Int16>  { typedef Int32  Type; };
-		/// Integer extended: UInt16 -> UInt32
-		template<> struct TypeExtend<UInt16> { typedef UInt32 Type; };
-		/// Integer extended: Int32 -> Int64
-		template<> struct TypeExtend<Int32>  { typedef Int64  Type; };
-		/// Integer extended: UInt32 -> UInt64
-		template<> struct TypeExtend<UInt32> { typedef UInt64 Type; };
+		/// Integer extended: C_Int8 -> C_Int16
+		template<> struct COREARRAY_DLL_DEFAULT TypeExtend<C_Int8>
+			{ typedef C_Int16  Type; };
+		/// Integer extended: C_UInt8 -> C_UInt16
+		template<> struct COREARRAY_DLL_DEFAULT TypeExtend<C_UInt8>
+			{ typedef C_UInt16 Type; };
+		/// Integer extended: C_Int16 -> C_Int32
+		template<> struct COREARRAY_DLL_DEFAULT TypeExtend<C_Int16>
+			{ typedef C_Int32  Type; };
+		/// Integer extended: C_UInt16 -> C_UInt32
+		template<> struct COREARRAY_DLL_DEFAULT TypeExtend<C_UInt16>
+			{ typedef C_UInt32 Type; };
+		/// Integer extended: C_Int32 -> C_Int64
+		template<> struct COREARRAY_DLL_DEFAULT TypeExtend<C_Int32>
+			{ typedef C_Int64  Type; };
+		/// Integer extended: C_UInt32 -> C_UInt64
+		template<> struct COREARRAY_DLL_DEFAULT TypeExtend<C_UInt32>
+			{ typedef C_UInt64 Type; };
 	}
 
 
@@ -75,8 +83,8 @@ namespace CoreArray
 	 *  \tparam int_type   integer type storing the value
 	 *  \tparam mask       bit mask according to bits
 	**/
-	template<unsigned bits, bool is_signed, typename int_type, Int64 mask>
-		struct BIT_INTEGER
+	template<unsigned bits, bool is_signed, typename int_type, C_Int64 mask>
+		struct COREARRAY_DLL_DEFAULT BIT_INTEGER
 	{
 	public:
 		/// The integer type storing the value
@@ -158,145 +166,145 @@ namespace CoreArray
 	// *******************   unsigned integer   *******************
 
 	/// 1-bit unsigned integer
-	typedef BIT_INTEGER<1u,  false, UInt8, 0x01> Bit1;
+	typedef BIT_INTEGER<1u,  false, C_UInt8, 0x01> Bit1;
 	/// 2-bit unsigned integer
-	typedef BIT_INTEGER<2u,  false, UInt8, 0x03> Bit2;
+	typedef BIT_INTEGER<2u,  false, C_UInt8, 0x03> Bit2;
 	/// 3-bit unsigned integer
-	typedef BIT_INTEGER<3u,  false, UInt8, 0x07> Bit3;
+	typedef BIT_INTEGER<3u,  false, C_UInt8, 0x07> Bit3;
 	/// 4-bit unsigned integer
-	typedef BIT_INTEGER<4u,  false, UInt8, 0x0F> Bit4;
+	typedef BIT_INTEGER<4u,  false, C_UInt8, 0x0F> Bit4;
 	/// 5-bit unsigned integer
-	typedef BIT_INTEGER<5u,  false, UInt8, 0x1F> Bit5;
+	typedef BIT_INTEGER<5u,  false, C_UInt8, 0x1F> Bit5;
 	/// 6-bit unsigned integer
-	typedef BIT_INTEGER<6u,  false, UInt8, 0x3F> Bit6;
+	typedef BIT_INTEGER<6u,  false, C_UInt8, 0x3F> Bit6;
 	/// 7-bit unsigned integer
-	typedef BIT_INTEGER<7u,  false, UInt8, 0x7F> Bit7;
+	typedef BIT_INTEGER<7u,  false, C_UInt8, 0x7F> Bit7;
 	/// 8-bit unsigned integer
-	typedef BIT_INTEGER<8u,  false, UInt8, 0xFF> Bit8;
+	typedef BIT_INTEGER<8u,  false, C_UInt8, 0xFF> Bit8;
 
 	/// 9-bit unsigned integer
-	typedef BIT_INTEGER<9u,  false, UInt16, 0x01FF> Bit9;
+	typedef BIT_INTEGER<9u,  false, C_UInt16, 0x01FF> Bit9;
 	/// 10-bit unsigned integer
-	typedef BIT_INTEGER<10u, false, UInt16, 0x03FF> Bit10;
+	typedef BIT_INTEGER<10u, false, C_UInt16, 0x03FF> Bit10;
 	/// 11-bit unsigned integer
-	typedef BIT_INTEGER<11u, false, UInt16, 0x07FF> Bit11;
+	typedef BIT_INTEGER<11u, false, C_UInt16, 0x07FF> Bit11;
 	/// 12-bit unsigned integer
-	typedef BIT_INTEGER<12u, false, UInt16, 0x0FFF> Bit12;
+	typedef BIT_INTEGER<12u, false, C_UInt16, 0x0FFF> Bit12;
 	/// 13-bit unsigned integer
-	typedef BIT_INTEGER<13u, false, UInt16, 0x1FFF> Bit13;
+	typedef BIT_INTEGER<13u, false, C_UInt16, 0x1FFF> Bit13;
 	/// 14-bit unsigned integer
-	typedef BIT_INTEGER<14u, false, UInt16, 0x3FFF> Bit14;
+	typedef BIT_INTEGER<14u, false, C_UInt16, 0x3FFF> Bit14;
 	/// 15-bit unsigned integer
-	typedef BIT_INTEGER<15u, false, UInt16, 0x7FFF> Bit15;
+	typedef BIT_INTEGER<15u, false, C_UInt16, 0x7FFF> Bit15;
 	/// 16-bit unsigned integer
-	typedef BIT_INTEGER<16u, false, UInt16, 0xFFFF> Bit16;
+	typedef BIT_INTEGER<16u, false, C_UInt16, 0xFFFF> Bit16;
 
 	/// 17-bit unsigned integer
-	typedef BIT_INTEGER<17u, false, UInt32, 0x01FFFF> Bit17;
+	typedef BIT_INTEGER<17u, false, C_UInt32, 0x01FFFF> Bit17;
 	/// 18-bit unsigned integer
-	typedef BIT_INTEGER<18u, false, UInt32, 0x03FFFF> Bit18;
+	typedef BIT_INTEGER<18u, false, C_UInt32, 0x03FFFF> Bit18;
 	/// 19-bit unsigned integer
-	typedef BIT_INTEGER<19u, false, UInt32, 0x07FFFF> Bit19;
+	typedef BIT_INTEGER<19u, false, C_UInt32, 0x07FFFF> Bit19;
 	/// 20-bit unsigned integer
-	typedef BIT_INTEGER<20u, false, UInt32, 0x0FFFFF> Bit20;
+	typedef BIT_INTEGER<20u, false, C_UInt32, 0x0FFFFF> Bit20;
 	/// 21-bit unsigned integer
-	typedef BIT_INTEGER<21u, false, UInt32, 0x1FFFFF> Bit21;
+	typedef BIT_INTEGER<21u, false, C_UInt32, 0x1FFFFF> Bit21;
 	/// 22-bit unsigned integer
-	typedef BIT_INTEGER<22u, false, UInt32, 0x3FFFFF> Bit22;
+	typedef BIT_INTEGER<22u, false, C_UInt32, 0x3FFFFF> Bit22;
 	/// 23-bit unsigned integer
-	typedef BIT_INTEGER<23u, false, UInt32, 0x7FFFFF> Bit23;
+	typedef BIT_INTEGER<23u, false, C_UInt32, 0x7FFFFF> Bit23;
 	/// 24-bit unsigned integer
-	typedef BIT_INTEGER<24u, false, UInt32, 0xFFFFFF> Bit24;
+	typedef BIT_INTEGER<24u, false, C_UInt32, 0xFFFFFF> Bit24;
 	/// 24-bit unsigned integer
 	typedef Bit24                                     UInt24;
 
 	/// 25-bit unsigned integer
-	typedef BIT_INTEGER<25u, false, UInt32, 0x01FFFFFF> Bit25;
+	typedef BIT_INTEGER<25u, false, C_UInt32, 0x01FFFFFF> Bit25;
 	/// 26-bit unsigned integer
-	typedef BIT_INTEGER<26u, false, UInt32, 0x03FFFFFF> Bit26;
+	typedef BIT_INTEGER<26u, false, C_UInt32, 0x03FFFFFF> Bit26;
 	/// 27-bit unsigned integer
-	typedef BIT_INTEGER<27u, false, UInt32, 0x07FFFFFF> Bit27;
+	typedef BIT_INTEGER<27u, false, C_UInt32, 0x07FFFFFF> Bit27;
 	/// 28-bit unsigned integer
-	typedef BIT_INTEGER<28u, false, UInt32, 0x0FFFFFFF> Bit28;
+	typedef BIT_INTEGER<28u, false, C_UInt32, 0x0FFFFFFF> Bit28;
 	/// 29-bit unsigned integer
-	typedef BIT_INTEGER<29u, false, UInt32, 0x1FFFFFFF> Bit29;
+	typedef BIT_INTEGER<29u, false, C_UInt32, 0x1FFFFFFF> Bit29;
 	/// 30-bit unsigned integer
-	typedef BIT_INTEGER<30u, false, UInt32, 0x3FFFFFFF> Bit30;
+	typedef BIT_INTEGER<30u, false, C_UInt32, 0x3FFFFFFF> Bit30;
 	/// 31-bit unsigned integer
-	typedef BIT_INTEGER<31u, false, UInt32, 0x7FFFFFFF> Bit31;
+	typedef BIT_INTEGER<31u, false, C_UInt32, 0x7FFFFFFF> Bit31;
 	/// 32-bit unsigned integer
-	typedef BIT_INTEGER<32u, false, UInt32, 0xFFFFFFFF> Bit32;
+	typedef BIT_INTEGER<32u, false, C_UInt32, 0xFFFFFFFF> Bit32;
 
 
 	// *******************   signed integer   *******************
 
 	/// 2-bit signed integer
-	typedef BIT_INTEGER<2u,  true, Int8, 0x03> SBit2;
+	typedef BIT_INTEGER<2u,  true, C_Int8, 0x03> SBit2;
 	/// 3-bit signed integer
-	typedef BIT_INTEGER<3u,  true, Int8, 0x07> SBit3;
+	typedef BIT_INTEGER<3u,  true, C_Int8, 0x07> SBit3;
 	/// 4-bit signed integer
-	typedef BIT_INTEGER<4u,  true, Int8, 0x0F> SBit4;
+	typedef BIT_INTEGER<4u,  true, C_Int8, 0x0F> SBit4;
 	/// 5-bit signed integer
-	typedef BIT_INTEGER<5u,  true, Int8, 0x1F> SBit5;
+	typedef BIT_INTEGER<5u,  true, C_Int8, 0x1F> SBit5;
 	/// 6-bit signed integer
-	typedef BIT_INTEGER<6u,  true, Int8, 0x3F> SBit6;
+	typedef BIT_INTEGER<6u,  true, C_Int8, 0x3F> SBit6;
 	/// 7-bit signed integer
-	typedef BIT_INTEGER<7u,  true, Int8, 0x7F> SBit7;
+	typedef BIT_INTEGER<7u,  true, C_Int8, 0x7F> SBit7;
 	/// 8-bit signed integer
-	typedef BIT_INTEGER<8u,  true, Int8, 0xFF> SBit8;
+	typedef BIT_INTEGER<8u,  true, C_Int8, 0xFF> SBit8;
 
 	/// 9-bit signed integer
-	typedef BIT_INTEGER<9u,  true, Int16, 0x01FF> SBit9;
+	typedef BIT_INTEGER<9u,  true, C_Int16, 0x01FF> SBit9;
 	/// 10-bit signed integer
-	typedef BIT_INTEGER<10u, true, Int16, 0x03FF> SBit10;
+	typedef BIT_INTEGER<10u, true, C_Int16, 0x03FF> SBit10;
 	/// 11-bit signed integer
-	typedef BIT_INTEGER<11u, true, Int16, 0x07FF> SBit11;
+	typedef BIT_INTEGER<11u, true, C_Int16, 0x07FF> SBit11;
 	/// 12-bit signed integer
-	typedef BIT_INTEGER<12u, true, Int16, 0x0FFF> SBit12;
+	typedef BIT_INTEGER<12u, true, C_Int16, 0x0FFF> SBit12;
 	/// 13-bit signed integer
-	typedef BIT_INTEGER<13u, true, Int16, 0x1FFF> SBit13;
+	typedef BIT_INTEGER<13u, true, C_Int16, 0x1FFF> SBit13;
 	/// 14-bit signed integer
-	typedef BIT_INTEGER<14u, true, Int16, 0x3FFF> SBit14;
+	typedef BIT_INTEGER<14u, true, C_Int16, 0x3FFF> SBit14;
 	/// 15-bit signed integer
-	typedef BIT_INTEGER<15u, true, Int16, 0x7FFF> SBit15;
+	typedef BIT_INTEGER<15u, true, C_Int16, 0x7FFF> SBit15;
 	/// 16-bit signed integer
-	typedef BIT_INTEGER<16u, true, Int16, 0xFFFF> SBit16;
+	typedef BIT_INTEGER<16u, true, C_Int16, 0xFFFF> SBit16;
 
 	/// 17-bit signed integer
-	typedef BIT_INTEGER<17u, true, Int32, 0x01FFFF> SBit17;
+	typedef BIT_INTEGER<17u, true, C_Int32, 0x01FFFF> SBit17;
 	/// 18-bit signed integer
-	typedef BIT_INTEGER<18u, true, Int32, 0x03FFFF> SBit18;
+	typedef BIT_INTEGER<18u, true, C_Int32, 0x03FFFF> SBit18;
 	/// 19-bit signed integer
-	typedef BIT_INTEGER<19u, true, Int32, 0x07FFFF> SBit19;
+	typedef BIT_INTEGER<19u, true, C_Int32, 0x07FFFF> SBit19;
 	/// 20-bit signed integer
-	typedef BIT_INTEGER<20u, true, Int32, 0x0FFFFF> SBit20;
+	typedef BIT_INTEGER<20u, true, C_Int32, 0x0FFFFF> SBit20;
 	/// 21-bit signed integer
-	typedef BIT_INTEGER<21u, true, Int32, 0x1FFFFF> SBit21;
+	typedef BIT_INTEGER<21u, true, C_Int32, 0x1FFFFF> SBit21;
 	/// 22-bit signed integer
-	typedef BIT_INTEGER<22u, true, Int32, 0x3FFFFF> SBit22;
+	typedef BIT_INTEGER<22u, true, C_Int32, 0x3FFFFF> SBit22;
 	/// 23-bit signed integer
-	typedef BIT_INTEGER<23u, true, Int32, 0x7FFFFF> SBit23;
+	typedef BIT_INTEGER<23u, true, C_Int32, 0x7FFFFF> SBit23;
 	/// 24-bit signed integer
-	typedef BIT_INTEGER<24u, true, Int32, 0xFFFFFF> SBit24;
+	typedef BIT_INTEGER<24u, true, C_Int32, 0xFFFFFF> SBit24;
 	/// 24-bit signed integer
 	typedef SBit24                                  Int24;
 
 	/// 25-bit signed integer
-	typedef BIT_INTEGER<25u, true, Int32, 0x01FFFFFF> SBit25;
+	typedef BIT_INTEGER<25u, true, C_Int32, 0x01FFFFFF> SBit25;
 	/// 26-bit signed integer
-	typedef BIT_INTEGER<26u, true, Int32, 0x03FFFFFF> SBit26;
+	typedef BIT_INTEGER<26u, true, C_Int32, 0x03FFFFFF> SBit26;
 	/// 27-bit signed integer
-	typedef BIT_INTEGER<27u, true, Int32, 0x07FFFFFF> SBit27;
+	typedef BIT_INTEGER<27u, true, C_Int32, 0x07FFFFFF> SBit27;
 	/// 28-bit signed integer
-	typedef BIT_INTEGER<28u, true, Int32, 0x0FFFFFFF> SBit28;
+	typedef BIT_INTEGER<28u, true, C_Int32, 0x0FFFFFFF> SBit28;
 	/// 29-bit signed integer
-	typedef BIT_INTEGER<29u, true, Int32, 0x1FFFFFFF> SBit29;
+	typedef BIT_INTEGER<29u, true, C_Int32, 0x1FFFFFFF> SBit29;
 	/// 30-bit signed integer
-	typedef BIT_INTEGER<30u, true, Int32, 0x3FFFFFFF> SBit30;
+	typedef BIT_INTEGER<30u, true, C_Int32, 0x3FFFFFFF> SBit30;
 	/// 31-bit signed integer
-	typedef BIT_INTEGER<31u, true, Int32, 0x7FFFFFFF> SBit31;
+	typedef BIT_INTEGER<31u, true, C_Int32, 0x7FFFFFFF> SBit31;
 	/// 32-bit signed integer
-	typedef BIT_INTEGER<32u, true, Int32, 0xFFFFFFFF> SBit32;
+	typedef BIT_INTEGER<32u, true, C_Int32, 0xFFFFFFFF> SBit32;
 
 
 
@@ -320,8 +328,9 @@ namespace CoreArray
 	// "dSBit1" ... "dSBit32"
 	extern const char *SBitStreamNames[];
 
-	template<unsigned bits, bool is_signed, typename int_type, Int64 mask>
-		struct TdTraits< BIT_INTEGER<bits, is_signed, int_type, mask> >
+	template<unsigned bits, bool is_signed, typename int_type, C_Int64 mask>
+		struct COREARRAY_DLL_DEFAULT TdTraits
+		< BIT_INTEGER<bits, is_signed, int_type, mask> >
 	{
 		typedef typename BIT_INTEGER<bits, is_signed, int_type, mask>::IntType TType;
 		typedef TType ElmType;
@@ -329,7 +338,7 @@ namespace CoreArray
 		static const int trVal = COREARRAY_TR_BIT_INTEGER;
 		static const unsigned BitOf = bits;
 		static const bool isClass = false;
-		static const TSVType SVType = svCustomInt;
+		static const C_SVType SVType = svCustomInt;
 
 		static const char * StreamName()
 		{
@@ -340,12 +349,12 @@ namespace CoreArray
 		}
 		static const char * TraitName() { return StreamName()+1; }
 
-		COREARRAY_INLINE static Int64 Min()
+		COREARRAY_INLINE static C_Int64 Min()
 		{
-			return is_signed ? (Int64(-1) << (bits-1)) : 0;
+			return is_signed ? (C_Int64(-1) << (bits-1)) : 0;
 		}
 
-		COREARRAY_INLINE static Int64 Max()
+		COREARRAY_INLINE static C_Int64 Max()
 		{
 			return is_signed ?
 				(BIT_INTEGER<bits, is_signed, int_type, mask>::BIT_MASK >> 1) :
@@ -354,4 +363,4 @@ namespace CoreArray
 	};
 }
 
-#endif /* _H_COREARRAY_BIT_ */
+#endif /* _HEADER_COREARRAY_BIT_ */
